Termine erfassen — Lino Tera Benutzerhandbuch

# Termine erfassen

Tipp: Bevor du Termine eingibst, solltest du in deinen Benutzereinstellungen prüfen, ob deine Dienstleistungsart* ausgefüllt ist.

Die Tabelle Meine Termine im Dashboard zeigt alle deine Termine ab heute. Um einen neuen Termin zu erfassen, klicke in der Startseite auf den Button hinter Meine Termine. Genauer gesagt zeigt diese Tabelle im Dashboard nur die ersten 15 Termine. Wenn du deren mehr hast, kannst du auf ⏏ klicken um sie alle zu sehen. Von dort aus kannst du auch Fehleingaben korrigieren oder bestehende Termine nachträglich bearbeiten, oder ebenfalls neue Termine einfügen mit dem Button in der Werkzeugleiste.

Wenn du so oder so auf klickst, zeigt Lino ein Dialogfenster, in dem du angeben musst:

- Datum und Uhrzeit. Wann der Termin stattgefunden hat (Beginn).

- Akte. Alle Termine außer Erstgespräche sollten einer Akte zugewiesen sein.

- Die Dienstleistungsart ist wichtig für Fakturierung und Statistik

- Die Kurzbeschreibung ist ein freier Text.

- In Betrag trägst du den eventuell kassierten Betrag ein. Termine mit einem Betrag stehen später in deiner Kassenrolle (siehe Barzahlungen).

Der neu erstellte Termin steht nun in deiner Tabelle Meine Termine.

Wenn du das Dialogfenster bestätigt hat, zeigt Lino den erstellten Termin in Vollbild-Ansicht.

Einen erstellten Termin kannst du bearbeiten, indem du auf den blauen Text in der Tabelle Meine Termine klickst. Lino zeigt dann das Detail-Fenster dieses Termins.

Hier kannst du die beim Erstellen eingegebenen Angaben falls nötig ändern, sowie weitere Angaben zu diesem Termin erfassen:

- Beschreibung : (zu klären, inwiefern es Sinn macht, hier Text einzugeben)

- Anwesenheiten : Lino fügt hier automatisch alle Patienten einer Akte als Gäste in den Termin ein.

- Workflow : Hier kannst du den Zustand des Termins sehen und ändern. Ein Termin kann folgende Zustände haben: Vorschlag / Entwurf / Stattgefunden / Storniert / Verpasst